summaryrefslogtreecommitdiff
path: root/jurt
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2004-05-19 09:28:42 +0000
committerKurt Zenker <kz@openoffice.org>2004-05-19 09:28:42 +0000
commitf3f1d6cc1032a58104850a8ed30e64c40eafc7f2 (patch)
tree1f372a99fbc14b13b56dff23ef72a58ddb4280a6 /jurt
parent619010ef8da07a32edf489d8dd9407e6b93f18b0 (diff)
INTEGRATION: CWS sdk10 (1.30.26); FILE MERGED
2004/05/06 14:08:38 mi 1.30.26.4: handles a dying server more gracefully 2004/02/03 14:45:55 mi 1.30.26.3: RESYNC: (1.30.24.1-1.33); FILE MERGED 2003/12/11 07:53:26 mi 1.30.26.2: RESYNC: (1.30-1.30.24.1); FILE MERGED 2003/11/27 15:51:25 sb 1.30.26.1: #i19974# After destroying a bridge, a newly created bridge with the same from/to pair as the old one will use the same java_environment as the old one, so make sure all proxies from the old bridge get removed from the java_environment when the old bridge is disposed.
Diffstat (limited to 'jurt')
-rw-r--r--jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java11
1 files changed, 7 insertions, 4 deletions
diff --git a/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java b/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
index 94f398189c21..6b8a3c990c10 100644
--- a/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
+++ b/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
@@ -2,9 +2,9 @@
*
* $RCSfile: java_remote_bridge.java,v $
*
- * $Revision: 1.36 $
+ * $Revision: 1.37 $
*
- * last change: $Author: rt $ $Date: 2004-03-30 16:19:12 $
+ * last change: $Author: kz $ $Date: 2004-05-19 10:28:42 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -100,6 +100,7 @@ import com.sun.star.lang.XMultiServiceFactory;
import com.sun.star.lang.XSingleServiceFactory;
import com.sun.star.lang.DisposedException;
+import com.sun.star.lib.uno.environments.java.java_environment;
import com.sun.star.lib.uno.environments.remote.IMessage;
import com.sun.star.lib.uno.environments.remote.IProtocol;
import com.sun.star.lib.uno.environments.remote.IReceiver;
@@ -127,7 +128,7 @@ import com.sun.star.uno.Any;
* The protocol to used is passed by name, the bridge
* then looks for it under <code>com.sun.star.lib.uno.protocols</code>.
* <p>
- * @version $Revision: 1.36 $ $ $Date: 2004-03-30 16:19:12 $
+ * @version $Revision: 1.37 $ $ $Date: 2004-05-19 10:28:42 $
* @author Kay Ramme
* @see com.sun.star.lib.uno.environments.remote.IProtocol
* @since UDK1.0
@@ -754,8 +755,10 @@ public class java_remote_bridge
// interrupt all jobs queued by this bridge
_iThreadPool.dispose(throwable);
// release all outmapped objects
freeHolders();
+ // assert _java_environment instanceof java_environment;
+ ((java_environment) _java_environment).revokeAllProxies();
if (DEBUG) {
if (_life_count != 0) {
@@ -754,8 +755,10 @@ public class java_remote_bridge
// interrupt all jobs queued by this bridge
_iThreadPool.dispose(throwable);
- // release all outmapped objects
+ // release all out-mapped objects and all in-mapped proxies:
freeHolders();